@@ -37,11 +37,11 @@ fn is_trunk_installed() -> bool {
         .unwrap_or(false)
 }
 
-fn is_appropriate_tauri_cli_installed(alpha: bool) -> bool {
+fn is_appropriate_tauri_cli_installed(beta: bool) -> bool {
     let check = |o: Output| match o.status.success() {
         true => String::from_utf8_lossy(&o.stdout)
             .split_once(' ')
-            .map(|(_, v)| v.starts_with(if alpha { '2' } else { '1' }))
+            .map(|(_, v)| v.starts_with(if beta { '2' } else { '1' }))
             .unwrap_or(false),
         s => s,
     };
@@ -111,9 +111,9 @@ fn is_webview2_installed() -> bool {
     target_os = "openbsd",
     target_os = "netbsd"
 ))]
-fn is_webkit2gtk_installed(alpha: bool) -> bool {
+fn is_webkit2gtk_installed(beta: bool) -> bool {
     Command::new("pkg-config")
-        .arg(if alpha {
+        .arg(if beta {
             "webkit2gtk-4.1"
         } else {
             "webkit2gtk-4.0"
@@ -155,7 +155,7 @@ struct Dep<'a> {
 }
 
 /// Print missing deps in a table and returns whether there was any missing deps.
-pub fn print_missing_deps(pkg_manager: PackageManager, template: Template, alpha: bool) -> bool {
+pub fn print_missing_deps(pkg_manager: PackageManager, template: Template, beta: bool) -> bool {
     let rustc_installed = is_rustc_installed();
     let cargo_installed = is_cargo_installed();
 
@@ -167,7 +167,7 @@ pub fn print_missing_deps(pkg_manager: PackageManager, template: Template, alpha
         target_os = "netbsd"
     ))]
     let (webkit2gtk_installed, rsvg2_installed) =
-        (is_webkit2gtk_installed(alpha), is_rsvg2_installed());
+        (is_webkit2gtk_installed(beta), is_rsvg2_installed());
 
     let deps: &[Dep<'_>] = &[
         Dep {
@@ -190,12 +190,12 @@ pub fn print_missing_deps(pkg_manager: PackageManager, template: Template, alpha
         },
         Dep {
             name: "Tauri CLI",
-            instruction: if alpha {
+            instruction: if beta {
                 format!("Run `{BLUE}{BOLD}cargo install tauri-cli --version '^2.0.0-beta'{RESET}`")
             } else {
                 format!("Run `{BLUE}{BOLD}cargo install tauri-cli{RESET}`")
             },
-            exists: &|| is_appropriate_tauri_cli_installed(alpha),
+            exists: &|| is_appropriate_tauri_cli_installed(beta),
             skip: pkg_manager.is_node() || !template.needs_tauri_cli(),
         },
         Dep {
@@ -232,8 +232,8 @@ pub fn print_missing_deps(pkg_manager: PackageManager, template: Template, alpha
         ))]
         Dep {
             name: "webkit2gtk & rsvg2",
-            instruction: format!("Visit {BLUE}{BOLD}{}{RESET}", if alpha {
-                "https://next--tauri.netlify.app/next/guides/getting-started/prerequisites/linux#1-system-dependencies"
+            instruction: format!("Visit {BLUE}{BOLD}{}{RESET}", if beta {
+                "https://beta.tauri.app/guides/prerequisites/#linux"
             } else {
                 "https://tauri.app/v1/guides/getting-started/prerequisites#setting-up-linux"
             }),
@@ -249,8 +249,8 @@ pub fn print_missing_deps(pkg_manager: PackageManager, template: Template, alpha
         ))]
         Dep {
             name: "webkit2gtk",
-            instruction: format!("Visit {BLUE}{BOLD}{}{RESET}", if alpha {
-                "https://next--tauri.netlify.app/next/guides/getting-started/prerequisites/linux#1-system-dependencies"
+            instruction: format!("Visit {BLUE}{BOLD}{}{RESET}", if beta {
+                "https://beta.tauri.app/guides/prerequisites/#linux"
             } else {
                 "https://tauri.app/v1/guides/getting-started/prerequisites#setting-up-linux"
             }),
@@ -266,8 +266,8 @@ pub fn print_missing_deps(pkg_manager: PackageManager, template: Template, alpha
         ))]
         Dep {
             name: "rsvg2",
-            instruction: format!("Visit {BLUE}{BOLD}{}{RESET}", if alpha {
-                "https://next--tauri.netlify.app/next/guides/getting-started/prerequisites/linux#1-system-dependencies"
+            instruction: format!("Visit {BLUE}{BOLD}{}{RESET}", if beta {
+                "https://beta.tauri.app/guides/prerequisites/#linux"
             } else {
                 "https://tauri.app/v1/guides/getting-started/prerequisites#setting-up-linux"
             }),
